Welcome to Python Object Getter  documentation!
=========================================================================================

.. include:: ../README.rst


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   contents/10_introduction
   contents/20_why_this_package
   contents/30_usage
   contents/40_modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
